#
# spec file for package alkimia
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum 8
%bcond_without released
Name:           alkimia
Version:        8.1.2
Release:        bp156.1.4
Summary:        Library with common classes and functionality used by finance applications
License:        LGPL-2.1-or-later
URL:            https://kmymoney.org/
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        alkimia.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  extra-cmake-modules
BuildRequires:  gmp-devel
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Package)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)

%description
libalkimia is a library with common classes and functionality used by finance
applications.

%package -n libalkimia5-%{sonum}
Summary:        Library with common classes and functionality used by finance applications

%description -n libalkimia5-%{sonum}
libalkimia is a library for Qt5 with common classes and functionality used by finance
applications.

%package -n libalkimia5-devel
Summary:        Development Files for libalkimia
Requires:       libalkimia5-%{sonum} = %{version}

%description -n libalkimia5-devel
The development files for libalkimia.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_WITH_WEBKIT=0 -DBUILD_APPLETS=0 -DENABLE_FINANCEQUOTE=1
%cmake_build

%install
%kf5_makeinstall -C build
mkdir -p %{buildroot}%{_datadir}/alkimia5/misc
mv %{buildroot}/alkimia5/misc/financequote.pl %{buildroot}%{_datadir}/alkimia5/misc/financequote.pl

%find_lang alkimia %{name}.lang
%find_lang onlinequoteseditor %{name}.lang
%find_lang plasma_applet_onlinequote %{name}.lang
%find_lang plasma_applet_org.wincak.foreigncurrencies2 %{name}.lang

%ldconfig_scriptlets -n libalkimia5-%{sonum}

%files
%license COPYING.LIB
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde
%dir %{_kf5_qmldir}/org/kde/alkimia
%{_kf5_applicationsdir}/org.kde.onlinequoteseditor5.desktop
%{_kf5_appstreamdir}/org.kde.onlinequoteseditor5.appdata.xml
%{_kf5_bindir}/onlinequoteseditor5
%{_kf5_iconsdir}/hicolor/*/apps/onlinequoteseditor5.*
%{_kf5_knsrcfilesdir}/alkimia-quotes.knsrc
%{_kf5_knsrcfilesdir}/kmymoney-quotes.knsrc
%{_kf5_knsrcfilesdir}/skrooge-quotes.knsrc
%{_kf5_qmldir}/org/kde/alkimia/libqmlalkimia.so
%{_kf5_qmldir}/org/kde/alkimia/qmldir
%{_kf5_sharedir}/alkimia5/

%files -n libalkimia5-devel
%license COPYING.LIB
%dir %{_includedir}/alkimia/
%{_includedir}/alkimia/Qt5
%{_kf5_cmakedir}/LibAlkimia5-*/
%{_kf5_libdir}/libalkimia5.so
%{_libdir}/pkgconfig/libalkimia5.pc

%files -n libalkimia5-%{sonum}
%license COPYING.LIB
%doc README.md
%{_kf5_libdir}/libalkimia5.so.%{sonum}*

%files lang -f %{name}.lang

%changelog
* Tue Oct 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 8.1.2. No changelog.
* Mon Jul  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.1.1. No changelog.
- Drop patch, fixed upstream:
  * 0001-Add-missing-QUrl-include-with-DBUILD_WITH_WEBENGINE.patch
* Wed Apr 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 8.1.0
  * Do not override the global translation domain of the application
  * Add support for skipping date extraction when a quote service
    does not provide a valid date
  * Fix bug not been able to rename local quote source
  * Many other bugfixes
- Update dependencies to build with KF5
- Drop upstream merged 0001-Use-new-KNS-install-location.patch
- Add patch from upstream:
  * 0001-Add-missing-QUrl-include-with-DBUILD_WITH_WEBENGINE.patch
* Sun Feb  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Use-new-KNS-install-location.patch
* Fri Feb  5 2021 Wang Jun <jgwang@suse.com>
- Update to version 8.0.4
  * Add initial QWebEngine support for KF5 builds
  * Add debug info for running perl script in
    AlkFinanceQuoteProcess::launch()
  * Add file menu with entry 'quit'
  * Add switch language entry to help menu
  * Add option ENABLE_FINANCEQUOTE and set to false by default on Windows
  * Bug and crash fixes
  * Fix fatal error caused by calling i18n in another thread initiated
  * Fix WebEngine/WebKit/Widgets backend choice
  * Fix 'alkimia fails to find mpirxx.h
  * Remove unused toolbar
* Sat Jan 11 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.3.
  * Add option to disable Webkit on KF5 builds
  * Bug and crash fixes
  * Don't hardcode the QML install dir
  * Fix integration of "Finance::Quote" sources into kmymoney
  * Export class AlkWebPage as wrapper for a generic web page
  * Fix installing and finding financequote.pl
  * Add experimental support for financequote.pl
* Mon Mar 25 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop the KDE4/Qt4 package.
* Thu Oct 25 2018 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner.
- Install the license file.
* Sat Apr 14 2018 wbauer@tmo.at
- update to version 7.0.2:
  * fix compiling kmymoney 4.8
* Fri Mar 16 2018 wbauer@tmo.at
- update to version 7.0.1:
  * now also supports MPIR instead of GMP
* Wed Jan 31 2018 wbauer@tmo.at
- Rename package to alkimia, following the upstream name
* Mon Jan 29 2018 nico.kruber@gmail.com
- update to version 7.0:
  * Fix AlkValue::operator=(QString) w/ valueRef()
  * Ported to Qt5, supports both Qt4 and Qt5 now
- thanks to users 'tittiatcoke' and 'wolfi323' for creating the
  initial unstable package out of the git repository
- enable package builds for both Qt4 and Qt5
- remove Fix-AlkValue-operator-QString-w-valueRef.patch (applied
  upstream)
* Tue Jul  4 2017 jengelh@inai.de
- Fix RPM groups.
* Sat Jul  1 2017 wbauer@tmo.at
- Update to version 5.0.0:
  * add support for newer versions of cmake (>=2.8.7)
  * use implicit sharing in AlkValue
- Add Fix-AlkValue-operator-QString-w-valueRef.patch to fix
  AlkValue::operator=(QString)
- Adjust Urls and file lists
* Fri Jan 20 2012 asterios.dramis@gmail.com
- Update to version 4.3.2:
  * Bugfix release.
* Tue Aug  9 2011 asterios.dramis@gmail.com
- Initial release (version 4.3.1).
